==> bouml_2.2.2.tar.gz: bouml_2.2.2/src/dialog/KeyValueTable.cpp <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#include <stdio.h>
#include <qpopupmenu.h> 

#include "KeyValueTable.h"
#include "HaveKeyValueData.h"
#include "KeyValueData.h"

KeyValuesTable::KeyValuesTable(HaveKeyValueData * hv, QWidget * parent, bool visit)
: StringTable(((hv == 0) ? 0 : hv->get_n_keys()) + 1, (visit) ? 2 : 3, parent, visit) {
  horizontalHeader()->setLabel(0, "Key");
  horizontalHeader()->setLabel(1, "Value");
  if (! visit)
    horizontalHeader()->setLabel(2, "*");
  
  int index;
  int sup = (hv == 0) ? 0 : hv->get_n_keys();
  
  if (visit) {
    for (index = 0; index < sup; index += 1) {
      TableItem * ti;
      
      ti = new TableItem(this, QTableItem::Never, hv->get_key(index));
      ti->setReplaceable(FALSE);
      setItem(index, 0, ti);
      
      ti = new TableItem(this, QTableItem::Never, hv->get_value(index));
      ti->setReplaceable(FALSE);
      setItem(index, 1, ti);
    }
  }
  else {
    for (index = 0; index < sup; index += 1){
      setText(index, 0, hv->get_key(index));
      setText(index, 1, hv->get_value(index));
      setText(index, 2, QString::null);
    }
    
    setText(index, 0, QString::null);
    setText(index, 1, QString::null);
    setText(index, 2, QString::null);
  }
  
  horizontalHeader()->setResizeEnabled(TRUE, 0);  //setColumnStretchable (0, TRUE);
  setColumnStretchable (1, TRUE);
  if (! visit) {
    adjustColumn(2);
    setColumnStretchable (2, FALSE);
  }
}

void KeyValuesTable::init_row(int index) {
  setText(index, 0, QString::null);
  setText(index, 1, QString::null);
  setText(index, 2, QString::null);
}

void KeyValuesTable::update(HaveKeyValueData * oper) {
  forceUpdateCells();
  
  unsigned n = numRows();
  unsigned index;
  
  if (text(n - 1, 0).isEmpty())
    n -= 1;
  
  oper->set_n_keys(n);
  
  for (index = 0; index != n; index += 1) {
    oper->set_key(index, text(index, 0));
    oper->set_value(index, text(index, 1));
  }
}

==> bouml_2.5.2.tar.gz: bouml_2.5.2/src/dialog/KeyValueTable.cpp <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#include <stdio.h>
#include <qpopupmenu.h> 

#include "KeyValueTable.h"
#include "HaveKeyValueData.h"
#include "KeyValueData.h"
#include "MLinesItem.h"

KeyValuesTable::KeyValuesTable(HaveKeyValueData * hv, QWidget * parent, bool visit)
    : StringTable(((hv == 0) ? 0 : hv->get_n_keys()) + 1,
		  (visit) ? 2 : 3, parent, visit) {
  horizontalHeader()->setLabel(0, "Key");
  horizontalHeader()->setLabel(1, "Value");
  if (! visit)
    horizontalHeader()->setLabel(2, "do");
  
  int index;
  int sup = (hv == 0) ? 0 : hv->get_n_keys();
  
  if (visit) {
    for (index = 0; index < sup; index += 1) {
      TableItem * ti;
      
      ti = new TableItem(this, QTableItem::Never, hv->get_key(index));
      ti->setReplaceable(FALSE);
      setItem(index, 0, ti);
      
      ti = new TableItem(this, QTableItem::Never, hv->get_value(index));
      ti->setReplaceable(FALSE);
      setItem(index, 1, ti);
    }
  }
  else {
    for (index = 0; index < sup; index += 1){
      setText(index, 0, hv->get_key(index));
      setItem(index, 1, new MLinesItem(this, hv->get_value(index)));
      setText(index, 2, QString::null);
      setRowStretchable(index, TRUE);
    }
    
    setText(index, 0, QString::null);
    setItem(index, 1, new MLinesItem(this, QString::null));
    setText(index, 2, QString::null);
    setRowStretchable(index, TRUE);
  }
  
  horizontalHeader()->setResizeEnabled(TRUE, 0);  //setColumnStretchable (0, TRUE);
  setColumnStretchable (1, TRUE);
  if (! visit) {
    adjustColumn(2);
    setColumnStretchable (2, FALSE);
  }
}

void KeyValuesTable::init_row(int index) {
  setText(index, 0, QString::null);
  setItem(index, 1, new MLinesItem(this, QString::null));
  setText(index, 2, QString::null);
  setRowStretchable(index, TRUE);
}

void KeyValuesTable::update(HaveKeyValueData * oper) {
  forceUpdateCells();
  
  unsigned n = numRows();
  unsigned index;
  
  if (text(n - 1, 0).isEmpty())
    n -= 1;
  
  oper->set_n_keys(n);
  
  for (index = 0; index != n; index += 1) {
    oper->set_key(index, text(index, 0));
    oper->set_value(index, text(index, 1));
  }
}
